#
# spec file for package qxmledit
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major   0

Name:           qxmledit
Version:        0.9.4
Release:        3.4
Summary:        Simple XML Editor and XSD Viewer
License:        LGPL-2.0+ and LGPL-3.0+
Group:          Productivity/Publishing/XML
Url:            http://qxmledit.org/
Source0:        https://github.com/lbellonda/qxmledit/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        http://qxmledit.org/tutorials/xsltmode.pdf
Source99:       baselibs.conf
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
%else
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(QtSql)
BuildRequires:  pkgconfig(QtSvg)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(QtXmlPatterns)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
QXmlEdit is a simple XML editor written in Qt4. Its main features are
unusual data visualization modes, nice XML manipulation and presentation and
it is multi platform. It can split very big XML files into fragments, and
compare XML files. It is one of the few graphical Open Source XSD viewers.

Main features:

* Hierarchical customizable view of XML elements.
* Fast XML hierarchy navigation.
* Split of big XML files.
* Search supporting XPath expressions.
* Base 64 data handling.
* Custom visualization styles.
* XML Schema (XSD) viewer.
* Columnar view.
* Sessions handling.
* Graphical XML file view.
* Map view of a XML document.
* Split and fragment extraction of big XML files.
* Visual compare of XML Schema files.
* Visual compare of XML files.
* XML Snippets.
* XSL specialized mode.
* Element display via user customizable rules.

%package -n libqxmledit%{major}
Summary:        Simple XML Editor Shared Libraries
Group:          System/Libraries

%description -n libqxmledit%{major}
QXmlEdit is a simple XML editor written in Qt4. It uses a tree based
interface to ease the edit of long files.

This package includes QXmlEdit shared libraries.

%package devel
Summary:        Simple XML Editor Development Files
Group:          Development/Libraries/C and C++
Requires:       libqxmledit%{major} = %{version}

%description devel
QXmlEdit is a simple XML editor written in Qt4. It uses a tree based
interface to ease the edit of long files.

This package includes QXmlEdit development files.

%prep
%setup -q

%build
export QXMLEDIT_INST_DATA_DIR=%{_datadir}/%{name}/
export QXMLEDIT_INST_DIR=%{_bindir}/
export QXMLEDIT_INST_DOC_DIR=%{_defaultdocdir}/%{name}/
export QXMLEDIT_INST_INCLUDE_DIR=%{_includedir}/%{name}/
export QXMLEDIT_INST_LIB_DIR=%{_libdir}/
export QXMLEDIT_INST_TRANSLATIONSDIR=%{_datadir}/%{name}/translations/
export QXMLEDIT_INST_USE_C11=y
export QXMLEDIT_NO_QWTPLOT=y
%if 0%{?suse_version} > 1320
qmake-qt5 \
%else
qmake \
%endif
    QMAKE_CFLAGS+="%{optflags}" \
    QMAKE_CXXFLAGS+="%{optflags}" \
    QMAKE_STRIP="true"
make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install

cp %{SOURCE1} .

# Install icons.
install -Dm 0644 install_scripts/environment/icon/qxmledit_48x48.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -Dm 0644 src/images/icon.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

# Install an appdata file.
install -Dm 0644 install_scripts/environment/desktop/QXmlEdit.appdata.xml \
    %{buildroot}%{_datadir}/appdata/QXmlEdit.appdata.xml

# Install a desktop file.
install -Dm 0644 install_scripts/environment/desktop/QXmlEdit.desktop \
    %{buildroot}%{_datadir}/applications/QXmlEdit.desktop

# Install a manual page.
install -Dm 0644 install_scripts/environment/man/%{name}.1 \
    %{buildroot}%{_mandir}/man1/%{name}.1

# Remove redundant files.
rm -f \
    %{buildroot}%{_datadir}/%{name}/{QXmlEdit.appdata.xml,QXmlEdit.desktop}

%suse_update_desktop_file QXmlEdit TextEditor Development Documentation Qt

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libqxmledit%{major} -p /sbin/ldconfig

%postun -n libqxmledit%{major} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING GPLV3.txt LGPLV3.txt NEWS README ROADMAP TODO
%doc doc/QXmlEdit_manual.pdf xsltmode.pdf
%{_bindir}/%{name}
%{_datadir}/%{name}/
%if 0%{?suse_version} && 0%{?suse_version} < 1320
%dir %{_datadir}/appdata/
%endif
%{_datadir}/appdata/QXmlEdit.appdata.xml
%{_datadir}/applications/QXmlEdit.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_mandir}/man?/*

%files -n libqxmledit%{major}
%defattr(-,root,root,-)
%{_libdir}/libQXmlEdit*.so.*

%files devel
%defattr(-,root,root,-)
%doc AUTHORS COPYING GPLV3.txt LGPLV3.txt NEWS README ROADMAP TODO
%{_includedir}/%{name}/
%{_libdir}/libQXmlEdit*.so

%changelog
* Tue Jun  7 2016 lazy.kent@opensuse.org
- Update to 0.9.4.
  * Option to override stream saving to handle 8 bit non ASCII like
    encodings (EBCDIC) when Qt has problems.
  * Fixed an issue with contribution module and isnan definition.
  * Fixed issue #36 Compilation error in openSUSE c++11
    compatibility.
  * Fixed a problem with file encoding with multibyte characters
    and attribute alignment.
  * New editor for XSD facets.
  * Changed the formatting of the data in binary viewer.
  * New dialog box to choose the detail level of the editor at the
    startup and recalled via menu.
  * Created the "Task" menu.
  * Enforced limits in the data extraction panel.
  * Enriched the export statistics of view data panel.
  * Attributes sorted case insensitive.
  * Asynchronous loading of data in Data Visualization dialog.
- Drop qxmledit-c++11_compatibility.patch: fixed upstream.
* Thu May 26 2016 lazy.kent@opensuse.org
- Add qxmledit-c++11_compatibility.patch: fix compilation error in
  openSUSE c++11 compatibility.
* Sat May 21 2016 lazy.kent@opensuse.org
- Update to 0.9.3.1.
  * No changes for Linux users.
- Correct the source URL.
* Tue May  3 2016 dimstar@opensuse.org
- Do not rename the desktop file and appdata.xml while installing
  them: the .desktop name is referenced in the .appdata.xml file
  and is in fact an ID for the application.
* Sun Mar  6 2016 lazy.kent@opensuse.org
- Update to 0.9.3.
  * Added an option to show or hide the element icon in the editor.
  * Added man page.
  * Added a command line option for anonymization.
  * Added a delete siblings feature.
  * Fixed small memory leaks.
  * Fixed a bug in the save search terms that was writing more than
    one time the same item.
  * Implemented the sorting of attributes in the current element or
    in all the file.
  * New option to limit the attributes line length to a given
    column.
  * Option to show the attributes alphabetically sorted.
  * Fixed a bug on the single instance application option saving.
  * Export the selected element to file.
  * New menu to show the containing folder in system browser.
  * Fixed a bug on XSLT element insert.
  * New option for set attribute maximum offset from element tag
    when saving.
  * New tool button for indentation settings.
- Install a man page manually.
* Fri Jan  8 2016 lazy.kent@opensuse.org
- Update to 0.9.2.
  * After a search operation the menu status is evaluated.
  * Fixed a regression on "New".
  * The search panel on session data is now opening on request.
  * New close window menu item.
  * Project option to disable precompiled headers.
  * New flags for fill data.
  * Clone elements tool.
* Tue Dec  1 2015 lazy.kent@opensuse.org
- Update to 0.9.1.
  * New tool: fill serie to fill a set of elements with consecutive
    values.
  * Variants of base 64 handled in the base 64 dialog.
  * Fixed some behavior on file reopen.
  * Enabled the application single instance via a configuration
    key.
  * Inserted a menu to raise all the windows.
  * Parified the behavior of the first windows to the other ones.
  * Fixed a bug that did not show an error message when opening an
    invalid XML file.
  * The application is now single instance when invoked from
    command line.
  * New option to show text in tooltip as a base 64 coded image.
* Thu Oct  1 2015 lazy.kent@opensuse.org
- Update to 0.9.0.
  * Enabled source code compatibility with Qt 4.7.3.
  * Disabled edit of text elements when clicking on CDATA checkbox
    in edit element panel.
  * Added a new menu item for closing the siblings of the
    selection.
  * DTD declaration editable in the "Info" dialog.
  * Handled the DTD declaration on load and save.
  * Added an option to preserve attributes order when saving.
  * Added an option to open a file using the current editor or a
    new window reversing the settings.
  * Open a new file by default happens in a new editor windows.
    Options to revert this behaviour.
  * Added a library of predefined namespaces.
  * Accepted drop files on Base64 dialog.
  * Matched tag names and structure to GitHub conventions.
  * Namespace management in edit element.
  * User defined namespace management and storage in embedded
    database.
  * Moved the I/O to StAX using QXmlStream.
* Sun Aug  9 2015 lazy.kent@opensuse.org
- Update to 0.8.17.
  * Updated the license on some header files.
  * New mennu for XSI related commands.
  * New feature: insert xsi type attribute.
  * New feature: remove xsi type attribute.
  * New feature: insert xsi nil attribute.
  * New feature: remove xsi nil attribute.
- Correct License tag.
* Tue Jul 14 2015 tittiatcoke@gmail.com
- Enable build against Qt5 for openSUSE Tumbleweed
* Sun Jul 12 2015 lazy.kent@opensuse.org
- Update to 0.8.16.
  * Changed the default for display children size to false.
  * Restored indentation settings after reload operation.
  * Optionally versioned libraries.
  * Dashed border on optional attributes and elements in the XSD
    view.
  * Added information about the current file.
  * Option to show/hide main the staus bar.
  * Option to show/hide main window buttons.
  * Added double click action on labels on the status bar (Read
    Only, Sessions and Indentation).
* Sun Jun 14 2015 lazy.kent@opensuse.org
- Update to 0.8.15.
  * Added an information function to detect XML Schema references
    and namespaces.
  * Added shortcuts for insert and delete elements.
  * Removed validation error dialog, highlighted the target object
    in the editor.
  * Updated shortcuts for new functions and avoid MacOS key binding
    clash.
  * Updated Desktop file.
  * Added a tooltip with annotations in the XSD view.
  * Per editor indentation settings.
  * Used the same options for compiler for the main project and
    tests.
  * Removed unsupported display mode and option.
  * Added scripts to work with git.
  * Added a selective replacement feature.
  * Added XSD toolbutton to the main toolbar.
  * Enabled by default precompiled headers on all projects.
  * Renamed the application qmake project.
  * Changed the target name to all lowercase for better Linux
    compatibility.
  * Added a edit XSD annotation panel.
  * Inserted a search next/previous.
- Correct the project URL.
* Wed Mar 18 2015 lazy.kent@opensuse.org
- Update to 0.8.14.
  * Now XML Schema menu is a tear off for faster access.
  * Moved the menu for compare to "Tools".
  * New search types: comments and base64 coded text.
  * Inserted an export to C raw data or Java characters in Unicode
    from the encoding dialog.
  * Added a dialog for an anonymization of a file without loading
    it in the editor.
  * Added an import exceptions from CSV for the anonymize dialog.
* Tue Jan  6 2015 lazy.kent@opensuse.org
- Update to 0.8.13.
  * Completed the anonymization module with exceptions and a
    preview.
  * Moved the anonymization module to the main application.
* Fri Nov 28 2014 lazy.kent@opensuse.org
- Update to 0.8.12.
  * Added a quick reference for xsd elements structure.
  * Created a basic anonymize feature.
  * Added a license agreement dialog on the first program usage.
  * Added a XSD wizard to insert or modify types of attributes or
    elements.
  * Added a non modal behavior for dialogs called from the
    application desktop menu.
  * Added some XSD validations for attributes, elements and types.
  * Fixed a bug on annotations display in XSD window.
  * Added an Unicode character details view.
  * Added some tools menu to the tray icon.
  * Selection between the editor and XSD windows.
  * Aligned the text in the encoding dialog.
  * Added the possbility to display the unicode character name in
    the encoding dialogs.
  * Added a support for desktop icon notifications.
  * Sorted the attributes by name in the tooltip.
- Remove BuildRequires: appdata-tools.
- Change download URL to sourceforge.net.
* Sat Jul 26 2014 lazy.kent@opensuse.org
- Update to 0.8.11.
  * Added an appdata file.
  * Removed the explore mode.
  * Fixed some problems in compare XSD files.
  * Added an option to show all the comment's text in the compact
    view.
  * Added an option to show imported and included schema in the XSD
    viewer.
  * Shown the attribute groups in the XSD navigator.
  * Handled the namespaces in the XSD viewer.
  * Fixed the search using XPath that did not close the unaffected
    elements.
  * Fixed some XSD error message.
  * Changed the xsd visualization direction from vertical to
    horizontal.
  * Added "insert parent" and "remove parent" methods.
  * Added insert child container undoable method.
- Rename libxmledit to libqxmledit.
- BuldReqires: appdata-tools for openSUSE >= 13.2.
* Sat Apr  5 2014 lazy.kent@opensuse.org
- Correct baselibs.conf.
* Thu Apr  3 2014 lazy.kent@opensuse.org
- Update to 0.8.10.
  * Simplified display type configuration.
  * Fixed read only toolbar enabling.
  * Added a configuration dialog for color configuration.
  * Removed a limit on attributes length in the element editor.
  * Updated XSD visualization.
  * Added a custom delegate to display elements in one column.
  * Added a codepage info dialog.
  * Fixed a problem with default data when no session was open.
  * Fixed a bug about the maximum number of last open files.
  * Fixed a problem with update indicator painting.
- Changes in 0.8.9.1.
  * Fixed a problem with long text in edit text node from inside
    the edit element dialog.
- Changes in 0.8.9.
  * Encoding support.
  * Added an export to clipboard option.
  * Implemented a default session to show last files when no real
    sessions exist.
  * Save command now behaves as "save as" on new documents.
  * Added an option to automatically insert XML prolog on new
    document creation.
  * Added an insert XML prolog option.
  * Added an export to Java/JavaScript feature to save the XML as a
    string literal.
  * Added an export to C/C++ feature to save the XML as a string
    literal.
  * Added metadata as Processing Instruction with 'qxmledit'
    target.
  * Implemented optional background color in styles.
  * Fixed a problem with attributes containing special characters
    and html view.
  * Added a read only option to protect the document from casual
    editing.
  * Added a feature to load a binary file in the Base 64 panel.
  * Searchlets.
  * Binary files viewer.
  * Full support for Qt5.2.
- Rename a libqxmledit-devel subpackage to qxmledit-devel.
- Change a source URL.
- Update Description.
* Tue Nov 19 2013 lazy.kent@opensuse.org
- Update to 0.8.8-1
  * Limited the amount of information shown on the main window.
  * Simplified the XSLT context menu.
  * Edit dialogs modality set to Qt::WindowModal.
  * Used the user's document folder as default folder for open
    files if none previously open.
  * Added a menu to create a document from a snippet.
  * Added a Snippet Manager class for testability.
  * Added a Maven POM template.
  * Added a context menu on the items in the result panel.
  * Added an option to expand the selected element in the editor.
  * When pressing the CTRL key with the "128..255 sequence" button
    of the encoding dialog, the sequence start from 32.
  * Attributes are alphabetically sorted in the edit element
    dialog.
  * Centralized the clipboard handling. Now is possible to copy
    elements between windows and paste text.
  * Added base 64 translation in attribute editing.
  * Modified all the projects for Qt5.1.1 support.
  * Added a copy of an element representation in XML in the XSD
    editor.
  * Added a copy of a facet in a simple type restriction in the XSD
    editor.
  * Parameters of call-template handling in XSLT properties dialog.
  * Ordered alphabetically the attributes in edit element dialog.
  * Tooltips in the main editor.
  * Rules in custom display styles acting on data.
  * Use of icons in custom display styles.
  * Disabled in the XSD navigation view editor the expansion of
    items when double clicking on categories.
  * Disabled in the editor the expansion of items when double
    clicking.
  * Addes shortcuts to the edit element dialog.
  * Added options to XSD viewer context menu.
  * Added a command to paste the selected element as sibling.
  * Fixed issues: #31
    https://code.google.com/p/qxmledit/issues/detail?id=31
- Update Description.
* Tue Sep 24 2013 lazy.kent@opensuse.org
- Update to 0.8.7.
  * Changed some icons in XSD viewer.
  * Added a search results panel where only the elements that match
    the query are shown.
  * XSLT elements insert context menu suggestion.
  * Creation of new file from templates for XSL-FO, XSD and XSLT.
  * XSLT edit mode.
  * Autocomplete in the find box.
  * Raised all the compiler warnings to error level.
  * Fixed the uri comparison method in the schema loader.
  * Fixed file selection logic in compare files.
  * Fixed issues: #25
    http://code.google.com/p/qxmledit/issues/detail?id=25
- Add baselibs.conf as a source.
- Add docs to the -devel package.
- Add "How to use xslt edit mode" manual to the docs.
- Add manuals to the qxmledit package (as asked in the DISTRIBUTING
  file).
- Update Description.
* Tue Jun 11 2013 lazy.kent@opensuse.org
- Update to 0.8.6.1.
  * Changed the modality of windows.
  * Added new errors to the compiler.
  * Fixed issues:
    [#30] http://code.google.com/p/qxmledit/issues/detail?id=30
- Changes in 0.8.6.
  * Copy attributes.
  * Search panel can use XPath expressions.
  * Fixed a bug in the compare panel.
  * Fixed issues:
    [#29] http://code.google.com/p/qxmledit/issues/detail?id=29
* Fri Mar 15 2013 lazy.kent@opensuse.org
- Update to 0.8.5.
  * Fixed a bug on mixed contents editing.
  * Added a XML structure display dialog based on force-directed
    graph.
  * Added a compare function without need to load one of the files
    into the editor.
  * Added a panel to show xml structure as a force directed graph.
- Build doesn't require fdupes.
- Rename binary QXmlEdit to qxmledit.
* Fri Feb  8 2013 lazy.kent@opensuse.org
- Update to 0.8.4.
  * Changed default view options and style.
  * Changed the default style.
  * Implemented a brand new compare window.
  * Implemented a filter on attributes display.
  * Fixed issues:
    [#28] http://code.google.com/p/qxmledit/issues/detail?id=28
* Sat Sep 22 2012 lazy.kent@opensuse.org
- Update to 0.8.3.1.
  * Fixed an alignment in the session drawer widget.
* Wed Sep 19 2012 lazy.kent@opensuse.org
- Update to 0.8.3.
  * Added a background configuration for the diagram.
  * Added a table with the details of the XSD differences.
  * Added an invitation to the session tree widget.
  * Changed XSD item graphics.
  * Added explanation of the cause that prevent the load of an XML
    file.
  * Implemented visual compare of xsd.
  * Removed use of stdout from the test project to emit xml output
    compatible with xUnit.
  * Commented some unused parameters.
  * Deactivated a log.
  * Added formats to output messages utility functions.
  * Fixed issues:
    [#26] http://code.google.com/p/qxmledit/issues/detail?id=26
* Wed Jun  6 2012 lazy.kent@opensuse.org
- Update to 0.8.2.
  * Added a dialog to examine encodings.
  * Added a dialog to convert text from and from base 64.
  * Fixed an issue on base 64 encoding with UTF-8 encoding.
  * Enlarged the space for tag editing.
  * Added tests for undo.
  * The current path is shown in the edit element dialog.
  * Enabled undo on edit text nodes.
  * Enabled undo on edit elements.
  * Enabled undo on delete elements.
  * Enabled undo on move elements.
  * Fixed a bug in the copy element method.
  * Optionally link with qwtplot3d library for display of XML data
    statistics.
  * New highlighting methods in data display: dilate and max.
  * New measure type: payload.
  * Accept drop actions in data visualization widget.
* Mon Apr  9 2012 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Added an icon 48x48 as stated in Freedesktop standards.
  * New extraction split type using depth.
  * Added new include folder for widget only release.
  * Added visualization option to the welcome dialog.
  * Fixed a typo in the format string of paused session in the
    state widget.
  * Added command line parameter to load a file into visualization
    mode.
  * Added data visualization.
  * Added multiple windows management.
  * Added a split to the columnar view.
  * Fixed issues:
    [#24] http://code.google.com/p/qxmledit/issues/detail?id=24
    [#23] http://code.google.com/p/qxmledit/issues/detail?id=23
    [#22] http://code.google.com/p/qxmledit/issues/detail?id=22
    [#21] http://code.google.com/p/qxmledit/issues/detail?id=21
- Changes in 0.8.0.
  * Added a check if current file is modified when selecting a
    recent file from menu.
  * Enabled XSD suggestions.
  * Added a session handler subproject.
  * Put configuration classes in the application project.
- Changes in 0.7.2:
  * Fixed issues:
    [#19] http://code.google.com/p/qxmledit/issues/detail?id=19
- Changes in 0.7.1.
  * Put the library version number under Unix configuration.
  * Fixed issues:
    [#18] http://code.google.com/p/qxmledit/issues/detail?id=18
    [#17] http://code.google.com/p/qxmledit/issues/detail?id=17
- Drop "install" patch (fixed upstream).
- Use pkgconfig(*) as build dependencies.
- Split off libraries and development files.
- Recommends doc package.
* Sat Feb  4 2012 lazy.kent@opensuse.org
- Update to 0.7.0.
  * Added a library test project.
  * Added a modification indicator in the edit element dialog.
  * Added icons to main widget.
  * Transformed Regola into a read only tree model.
  * Added a window title for the library as global data.
  * Added a columnar view.
  * Split the project into an application and a library.
* Tue Jan 17 2012 lazy.kent@opensuse.org
- Update to 0.6.2.
  * New comparison option in XML extraction.
  * New filtering option in XML extraction.
  * Fixed issues:
    [#16] http://code.google.com/p/qxmledit/issues/detail?id=16
- Update "install" patch.
* Tue Jan  3 2012 lazy.kent@opensuse.org
- Update to 0.6.1.
  * New structure visualization.
  * Fixed issues:
    [#14] http://code.google.com/p/qxmledit/issues/detail?id=14
    [#15] http://code.google.com/p/qxmledit/issues/detail?id=15
* Sat Dec 24 2011 lazy.kent@opensuse.org
- Update to 0.6.0.
  * License changed to GNU Library General Public License v2 or
    later.
  * Added binary file loading and saving in text noded via base 64
    encoding.
  * Added a 'space' token as option in file splitting naming.
  * Mixed content handling.
  * Added "New with Schema" menu and dialog.
  * Added Schema files cache.
  * Added help icon.
  * Redesigned toolbar.
  * Added new tests.
  * Default fonts made configurable.
- Added Development;Documentation desktop category. Removed
  incorrect XMLUtility category.
* Sun Nov 13 2011 lazy.kent@opensuse.org
- Update to 0.5.4.
  * Czech translation updated.
  * Improved fragments extraction dialog with tooltips.
  * Trimmed split files input values.
  * Handled unusual cases on XML fragments navigation.
  * Added some images.
  * Fixed issues:
    [#12] http://code.google.com/p/qxmledit/issues/detail?id=12.
    [#13] http://code.google.com/p/qxmledit/issues/detail?id=13.
* Mon Oct 31 2011 lazy.kent@opensuse.org
- Update to 0.5.3.
  * Changed a system field in the extraction dialog.
  * Double clicking on recent files of welcome dialog load the
    file.
  * Forbid overwriting original file if mixed contents are
    detected.
  * Used a separate version for welcome dialog.
- Split off PDF manual.
- Make a symlink to name a binary the same as a package name.
- Removed obsolete "clean" section from spec.
* Tue Sep  6 2011 lazy.kent@opensuse.org
- Update to 0.5.1.
  * Export of the XSD diagram as SVG or PDF.
  * Added grouping option on last item in search in file dialog.
  * Added a navigation pane to XSD viewer.
  * Czech language localization.
- Build requires libqt4-devel >= 4.7.
- "install" patch replaced with the new one.
* Sun Jul 24 2011 lazy.kent@opensuse.org
- Update to 0.5.0.
  * Added a xsd file viewer accessible through the plugins menu.
  * Added a 'explore structure' mode to scan a large file.
  * Added a shortcut for the enter key in find edit box.
  * Added a delete bookmarked items command.
  * Added the option to show element size.
  * Added the option to show element text length.
  * Added an option to show elements modified in the work session
    with a colored marker on the margin of the first column.
  * Fixed issues::
    [#7] http://code.google.com/p/qxmledit/issues/detail?id=7.
- Build requires libqt4-devel >= 4.6 and hicolor-icon-theme.
- Updated install patch.
- Corrected License tag.
- Use full URL for source.
- Added qmake optflags.
- Added %%desktop_database_post/un and %%icon_theme_cache_post/un
  macros.
* Sun Oct 24 2010 lazy.kent@opensuse.org
- Update to 0.4.9.1.
  * Implemented w3c syntax compliant check on attribute and element
    names with the following limitation: only the Unicode Basic
    Multilingual Plane (BMP) is used.
  * Fixed issues:
    [#6] http://code.google.com/p/qxmledit/issues/detail?id=6.
* Tue Sep 21 2010 lazy.kent@opensuse.org
- Update to 0.4.9
  * XML Snippets.
  * Transform selection in snippet.
  * Balsamiq Plugin.
  * Auto test feature.
  * Set buddies in EditElement dialog.
  * Set correct viewer protocol and path in ConfigStyle dialog.
  * Fixed clone element bug on text nodes.
  * Fixed some dialogs alignments and layouts.
  * Fixed issues:
    [#3] (http://code.google.com/p/qxmledit/issues/detail?id=3)
    [#4] (http://code.google.com/p/qxmledit/issues/detail?id=4)
    [#5] (http://code.google.com/p/qxmledit/issues/detail?id=5).
- Install patch to fix path.
* Wed Jul 21 2010 lazy.kent@opensuse.org
- Initial package created - 0.4.7.
